==> qtjambi-uic-6.5.2-sources.jar: io/qt/uic/ui4/DomLayoutDefault.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomLayoutDefault</code></p>
 */
public class DomLayoutDefault extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>DomLayoutDefault()</code></p>
     */
    public DomLayoutDefault(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomLayoutDefault instance);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>attributeMargin()const</code></p>
     */
    @QtUninvokable
    public final int attributeMargin(){
        return attributeMargin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeMargin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>attributeSpacing()const</code></p>
     */
    @QtUninvokable
    public final int attributeSpacing(){
        return attributeSpacing_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeSpacing_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>clearAttributeMargin()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeMargin(){
        clearAttributeMargin_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeMargin_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>clearAttributeSpacing()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeSpacing(){
        clearAttributeSpacing_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeSpacing_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>hasAttributeMargin()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeMargin(){
        return hasAttributeMargin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeMargin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>hasAttributeSpacing()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeSpacing(){
        return hasAttributeSpacing_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeSpacing_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>setAttributeMargin(int)</code></p>
     */
    @QtUninvokable
    public final void setAttributeMargin(int a){
        setAttributeMargin_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeMargin_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>setAttributeSpacing(int)</code></p>
     */
    @QtUninvokable
    public final void setAttributeSpacing(int a){
        setAttributeSpacing_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeSpacing_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomLayoutDefault(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.5.7-sources.jar: io/qt/uic/ui4/DomLayoutDefault.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomLayoutDefault</code></p>
 * @hidden
 */
public class DomLayoutDefault extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>DomLayoutDefault()</code></p>
     */
    public DomLayoutDefault(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomLayoutDefault instance);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>attributeMargin()const</code></p>
     */
    @QtUninvokable
    public final int attributeMargin(){
        return attributeMargin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeMargin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>attributeSpacing()const</code></p>
     */
    @QtUninvokable
    public final int attributeSpacing(){
        return attributeSpacing_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeSpacing_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>clearAttributeMargin()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeMargin(){
        clearAttributeMargin_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeMargin_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>clearAttributeSpacing()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeSpacing(){
        clearAttributeSpacing_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeSpacing_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>hasAttributeMargin()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeMargin(){
        return hasAttributeMargin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeMargin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>hasAttributeSpacing()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeSpacing(){
        return hasAttributeSpacing_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeSpacing_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>setAttributeMargin(int)</code></p>
     */
    @QtUninvokable
    public final void setAttributeMargin(int a){
        setAttributeMargin_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeMargin_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>setAttributeSpacing(int)</code></p>
     */
    @QtUninvokable
    public final void setAttributeSpacing(int a){
        setAttributeSpacing_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeSpacing_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomLayoutDefault::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomLayoutDefault(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}
